@@ -43,12 +43,12 @@ def Track(boxes, classes, confidence, frame):
         tracker.predict()
         tracker.update(detections)
     
-    for track, i in tracker.tracks:
+    for track in tracker.tracks:
         if not track.is_confirmed() or track.time_since_update > 1:
             continue
         bbox = track.to_tlbr()
-        cv2.rectangle(frame, (int(bbox[i][0]), int(bbox[i][1])), (int(bbox[i][2]), int(bbox[i][3])), (255, 255, 255), 2)
-        cv2.putText(frame, "ID: " + str(track.track_id), (int(bbox[i][0]), int(bbox[i][1])), 0,
+        # cv2.rectangle(frame, (int(bbox[i][0]), int(bbox[i][1])), (int(bbox[i][2]), int(bbox[i][3])), (255, 255, 255), 2)
+        cv2.putText(frame, "ID: " + str(track.track_id), (int(bbox[0]), int(bbox[1])), 0,
                     1.5e-3 * frame.shape[0], (0, 255, 0), 1)
     """
     for det in detections:
